==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ConnectionMonitorEndpointFilterItemArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterItemArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ConnectionMonitorEndpointFilterItemType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the connection monitor endpoint filter item.
 * @property address The address of the filter item.
 * @property type The type of item included in the filter. Currently only 'AgentAddress' is supported.
 */
public data class ConnectionMonitorEndpointFilterItemArgs(
    public val address: Output<String>? = null,
    public val type: Output<Either<String, ConnectionMonitorEndpointFilterItemType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterItemArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterItemArgs =
        com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterItemArgs.builder()
            .address(address?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectionMonitorEndpointFilterItemArgs].
 */
@PulumiTagMarker
public class ConnectionMonitorEndpointFilterItemArgsBuilder internal constructor() {
    private var address: Output<String>? = null

    private var type: Output<Either<String, ConnectionMonitorEndpointFilterItemType>>? = null

    /**
     * @param value The address of the filter item.
     */
    @JvmName("ybegavbyulgasvqv")
    public suspend fun address(`value`: Output<String>) {
        this.address = value
    }

    /**
     * @param value The type of item included in the filter. Currently only 'AgentAddress' is supported.
     */
    @JvmName("gvqcgcwlmvmxhilt")
    public suspend
    fun type(`value`: Output<Either<String, ConnectionMonitorEndpointFilterItemType>>) {
        this.type = value
    }

    /**
     * @param value The address of the filter item.
     */
    @JvmName("kpsmlamecesfxvtt")
    public suspend fun address(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.address = mapped
    }

    /**
     * @param value The type of item included in the filter. Currently only 'AgentAddress' is supported.
     */
    @JvmName("ouafrkumgusxpirs")
    public suspend fun type(`value`: Either<String, ConnectionMonitorEndpointFilterItemType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of item included in the filter. Currently only 'AgentAddress' is supported.
     */
    @JvmName("mlhhlkqayljkctol")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConnectionMonitorEndpointFilterItemType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of item included in the filter. Currently only 'AgentAddress' is supported.
     */
    @JvmName("ntliyjnjyacsfxgb")
    public fun type(`value`: ConnectionMonitorEndpointFilterItemType) {
        val toBeMapped = Either.ofRight<String, ConnectionMonitorEndpointFilterItemType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ConnectionMonitorEndpointFilterItemArgs =
        ConnectionMonitorEndpointFilterItemArgs(
            address = address,
            type = type,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ConnectionMonitorEndpointFilterItemArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterItemArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ConnectionMonitorEndpointFilterItemType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the connection monitor endpoint filter item.
 * @property address The address of the filter item.
 * @property type The type of item included in the filter. Currently only 'AgentAddress' is supported.
 */
public data class ConnectionMonitorEndpointFilterItemArgs(
    public val address: Output<String>? = null,
    public val type: Output<Either<String, ConnectionMonitorEndpointFilterItemType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterItemArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterItemArgs =
        com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterItemArgs.builder()
            .address(address?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectionMonitorEndpointFilterItemArgs].
 */
@PulumiTagMarker
public class ConnectionMonitorEndpointFilterItemArgsBuilder internal constructor() {
    private var address: Output<String>? = null

    private var type: Output<Either<String, ConnectionMonitorEndpointFilterItemType>>? = null

    /**
     * @param value The address of the filter item.
     */
    @JvmName("ukmpnseqrbvusyyk")
    public suspend fun address(`value`: Output<String>) {
        this.address = value
    }

    /**
     * @param value The type of item included in the filter. Currently only 'AgentAddress' is supported.
     */
    @JvmName("atkmyoqknjuwhems")
    public suspend
    fun type(`value`: Output<Either<String, ConnectionMonitorEndpointFilterItemType>>) {
        this.type = value
    }

    /**
     * @param value The address of the filter item.
     */
    @JvmName("fvjgaheaxjhnoiik")
    public suspend fun address(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.address = mapped
    }

    /**
     * @param value The type of item included in the filter. Currently only 'AgentAddress' is supported.
     */
    @JvmName("bwkfamegsaijkjva")
    public suspend fun type(`value`: Either<String, ConnectionMonitorEndpointFilterItemType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of item included in the filter. Currently only 'AgentAddress' is supported.
     */
    @JvmName("ebreoeeehdahpbic")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConnectionMonitorEndpointFilterItemType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of item included in the filter. Currently only 'AgentAddress' is supported.
     */
    @JvmName("jfcbgqrobwvkcnum")
    public fun type(`value`: ConnectionMonitorEndpointFilterItemType) {
        val toBeMapped = Either.ofRight<String, ConnectionMonitorEndpointFilterItemType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ConnectionMonitorEndpointFilterItemArgs =
        ConnectionMonitorEndpointFilterItemArgs(
            address = address,
            type = type,
        )
}
